#!/bin/bash

# 日志文件路径
LOG_FILE="/var/log/wifi_module_loader.log"

# 日志记录函数
log() {
    echo "$(date '+%Y-%m-%d %H:%M:%S') $1" >> "$LOG_FILE"
}

log "开始检查 wifi..."

# 定义支持的 PCIe 设备及其对应的模块
declare -A pci_device_map=(
    ["10ec:b852"]="8852be"
    ["10ec:c852"]="8852ce"
    ["10ec:a85a"]="8852ae"
    ["10ec:8922"]="8922ae"
    ["10ec:b851"]="8851be"
    ["10ec:c822"]="8822ce"
    ["10ec:c821"]="8821ce-vc"
)

wifi_5_15_devices=("10ec:b852" "10ec:c852" "10ec:a85a" "10ec:8922" "10ec:b851" "10ec:c822" "10ec:c821")

# 检查系统中是否存在指定的一个或多个 PCIe 设备
# 参数：一个或多个 VENDOR:DEVICE ID（如 "8086:1533"）
# 返回值：
#   0 - 至少有一个设备存在
#   1 - 所有设备都不存在
check_pci_devices_exist() {
    local found=1
    for dev_id in "$@"; do
        if lspci -n | grep -q "$dev_id"; then
            log "找到设备 $dev_id"
            found=0
            break
        fi
    done
    return $found
}

# 检查是否包含5.15 wifi
if check_pci_devices_exist "${wifi_5_15_devices[@]}"; then
    log "检测到5.15 wifi，放弃加载cfg80211模块..."
else
    log "未检测到5.15 wifi，继续加载cfg80211模块..."
	/sbin/insmod /lib/modules/$(uname -r)/kernel/net/wireless/cfg80211.ko
    exit 0
fi


log "WIFI 模块加载检查完成"
